@@ -15,6 +15,7 @@
 // Include Files							/*{{{*/
 #include <config.h>
 
+#include <apt-pkg/configuration.h>
 #include <apt-pkg/error.h>
 
 #include <algorithm>
@@ -242,3 +243,90 @@ void GlobalError::MergeWithStack() {
 	Stacks.pop_back();
 }
 									/*}}}*/
+
+// GlobalError::Item::operator<<						/*{{{*/
+APT_HIDDEN std::ostream &operator<<(std::ostream &out, GlobalError::Item i)
+{
+   static constexpr auto COLOR_RESET = "\033[0m";
+   static constexpr auto COLOR_NOTICE = "\033[33m";  // normal yellow
+   static constexpr auto COLOR_WARN = "\033[1;33m";  // bold yellow
+   static constexpr auto COLOR_ERROR = "\033[1;31m"; // bold red
+
+   bool use_color = _config->FindB("APT::Color", false);
+
+   if (use_color)
+   {
+      switch (i.Type)
+      {
+      case GlobalError::FATAL:
+      case GlobalError::ERROR:
+	 out << COLOR_ERROR;
+	 break;
+      case GlobalError::WARNING:
+	 out << COLOR_WARN;
+	 break;
+      case GlobalError::NOTICE:
+	 out << COLOR_NOTICE;
+	 break;
+      default:
+	 break;
+      }
+   }
+
+   switch (i.Type)
+   {
+   case GlobalError::FATAL:
+   case GlobalError::ERROR:
+      out << 'E';
+      break;
+   case GlobalError::WARNING:
+      out << 'W';
+      break;
+   case GlobalError::NOTICE:
+      out << 'N';
+      break;
+   case GlobalError::DEBUG:
+      out << 'D';
+      break;
+   }
+   out << ": ";
+
+   if (use_color)
+   {
+      switch (i.Type)
+      {
+      case GlobalError::FATAL:
+      case GlobalError::ERROR:
+      case GlobalError::WARNING:
+      case GlobalError::NOTICE:
+	 out << COLOR_RESET;
+	 break;
+      default:
+	 break;
+      }
+   }
+
+   std::string::size_type line_start = 0;
+   std::string::size_type line_end;
+   while ((line_end = i.Text.find_first_of("\n\r", line_start)) != std::string::npos)
+   {
+      if (line_start != 0)
+	 out << std::endl
+	     << "   ";
+      out << i.Text.substr(line_start, line_end - line_start);
+      line_start = i.Text.find_first_not_of("\n\r", line_end + 1);
+      if (line_start == std::string::npos)
+	 break;
+   }
+   if (line_start == 0)
+      out << i.Text;
+   else if (line_start != std::string::npos)
+      out << std::endl
+	  << "   " << i.Text.substr(line_start);
+
+   if (use_color)
+      out << COLOR_RESET;
+
+   return out;
+}
+									/*}}}*/
