@@ -597,7 +597,7 @@ string Base64Encode(const string &S)
       base64.  */
    for (string::const_iterator I = S.begin(); I < S.end(); I += 3)
    {
-      char Bits[3] = {0,0,0};
+      uint8_t Bits[3] = {0,0,0};
       Bits[0] = I[0];
       if (I + 1 < S.end())
 	 Bits[1] = I[1];
@@ -1044,10 +1044,6 @@ static time_t timegm(struct tm *t)
    we allow them here to to be able to reuse the method. Either way, a date
    must be in UTC or parsing will fail. Previous implementations of this
    method used to ignore the timezone and assume always UTC. */
-bool RFC1123StrToTime(const char* const str,time_t &time)
-{
-   return RFC1123StrToTime(std::string(str), time);
-}
 bool RFC1123StrToTime(std::string const &str,time_t &time)
 {
    unsigned short day = 0;
