@@ -11,10 +11,10 @@
 // Include Files							/*{{{*/
 #include <config.h>
 
+#include <apt-pkg/algorithms.h>
 #include <apt-pkg/aptconfiguration.h>
 #include <apt-pkg/cachefilter.h>
 #include <apt-pkg/configuration.h>
-#include <apt-pkg/crc-16.h>
 #include <apt-pkg/deblistparser.h>
 #include <apt-pkg/error.h>
 #include <apt-pkg/hashes.h>
@@ -166,8 +166,12 @@ bool debListParser::NewVersion(pkgCache::VerIterator &Ver)
    }
    // Parse the source package name
    pkgCache::GrpIterator G = Ver.ParentPkg().Group();
+
+   // Setup the defaults
    Ver->SourcePkgName = G->Name;
    Ver->SourceVerStr = Ver->VerStr;
+
+   // Parse the name and version str
    if (Section.Find(pkgTagSection::Key::Source,Start,Stop) == true)
    {
       const char * const Space = static_cast<const char *>(memchr(Start, ' ', Stop - Start));
@@ -194,33 +198,19 @@ bool debListParser::NewVersion(pkgCache::VerIterator &Ver)
       }
 
       APT::StringView const pkgname(Start, Stop - Start);
+      // Oh, our group is the wrong one for the source package. Make a new one.
       if (pkgname != G.Name())
       {
-	 for (pkgCache::PkgIterator P = G.PackageList(); P.end() == false; P = G.NextPkg(P))
-	 {
-	    for (V = P.VersionList(); V.end() == false; ++V)
-	    {
-	       if (pkgname == V.SourcePkgName())
-	       {
-		  Ver->SourcePkgName = V->SourcePkgName;
-		  break;
-	       }
-	    }
-	    if (V.end() == false)
-	       break;
-	 }
-	 if (V.end() == true)
-	 {
-	    pkgCache::GrpIterator SG;
-	    if (not NewGroup(SG, pkgname))
-	       return false;
-
-	    G = Ver.ParentPkg().Group();
-	    Ver->SourcePkgName = SG->Name;
-	 }
+	 if (not NewGroup(G, pkgname))
+	    return false;
       }
    }
 
+   // Link into by source package group.
+   Ver->SourcePkgName = G->Name;
+   Ver->NextInSource = G->VersionsInSource;
+   G->VersionsInSource = Ver.MapPointer();
+
    Ver->MultiArch = ParseMultiArch(true);
    // Archive Size
    Ver->Size = Section.FindULL(pkgTagSection::Key::Size);
@@ -257,14 +247,19 @@ bool debListParser::NewVersion(pkgCache::VerIterator &Ver)
    
    if (ParseProvides(Ver) == false)
       return false;
-   
+   if (not APT::KernelAutoRemoveHelper::getUname(Ver.ParentPkg().Name()).empty())
+   {
+      if (not NewProvides(Ver, "$kernel", "any", Ver.VerStr(), pkgCache::Flag::MultiArchImplicit))
+	 return false;
+   }
+
    return true;
 }
 									/*}}}*/
 // ListParser::AvailableDescriptionLanguages				/*{{{*/
 std::vector<std::string> debListParser::AvailableDescriptionLanguages()
 {
-   std::vector<std::string> const understood = APT::Configuration::getLanguages();
+   std::vector<std::string> const understood = APT::Configuration::getLanguages(true);
    std::vector<std::string> avail;
    static constexpr int prefixLen = 12;
    char buf[32] = "Description-";
@@ -329,6 +324,8 @@ bool debListParser::UsePackage(pkgCache::PkgIterator &Pkg,
 	 return false;
    if (Section.FindFlag(pkgTagSection::Key::Important,Pkg->Flags,pkgCache::Flag::Important) == false)
       return false;
+   if (Section.FindFlag(pkgTagSection::Key::Protected, Pkg->Flags, pkgCache::Flag::Important) == false)
+      return false;
 
    if (std::find(forceEssential.begin(), forceEssential.end(), Pkg.Name()) != forceEssential.end())
    {
@@ -349,7 +346,7 @@ bool debListParser::UsePackage(pkgCache::PkgIterator &Pkg,
 // ListParser::VersionHash - Compute a unique hash for this version	/*{{{*/
 // ---------------------------------------------------------------------
 /* */
-unsigned short debListParser::VersionHash()
+uint32_t debListParser::VersionHash()
 {
    static constexpr pkgTagSection::Key Sections[] ={
       pkgTagSection::Key::Installed_Size,
@@ -360,7 +357,7 @@ unsigned short debListParser::VersionHash()
       pkgTagSection::Key::Conflicts,
       pkgTagSection::Key::Breaks,
       pkgTagSection::Key::Replaces};
-   unsigned long Result = INIT_FCS;
+   unsigned long Result = 5381;
    for (auto I : Sections)
    {
       const char *Start;
@@ -381,7 +378,7 @@ unsigned short debListParser::VersionHash()
 	 }
 	 if (isspace_ascii(*Start) != 0 || *Start == '=')
 	    continue;
-	 Result = AddCRC16Byte(Result, tolower_ascii_unsafe(*Start));
+	 Result = 33 * Result + tolower_ascii_unsafe(*Start);
       }
 
 
@@ -480,7 +477,7 @@ bool debStatusListParser::ParseStatus(pkgCache::PkgIterator &Pkg,
       if (Ver.end() == true)
 	 _error->Warning("Encountered status field in a non-version description");
       else
-	 Pkg->CurrentVer = Ver.Index();
+	 Pkg->CurrentVer = Ver.MapPointer();
    }
    
    return true;
@@ -1001,7 +998,7 @@ unsigned char debListParser::GetPrio(string Str)
    return Out;
 }
 									/*}}}*/
-bool debListParser::SameVersion(unsigned short const Hash,		/*{{{*/
+bool debListParser::SameVersion(uint32_t Hash,		/*{{{*/
       pkgCache::VerIterator const &Ver)
 {
    if (pkgCacheListParser::SameVersion(Hash, Ver) == false)
