@@ -1,6 +1,5 @@
 // -*- mode: cpp; mode: fold -*-
 // Description								/*{{{*/
-// $Id: debrecords.h,v 1.8 2001/03/13 06:51:46 jgg Exp $
 /* ######################################################################
    
    Debian Package Records - Parser for debian package records
@@ -21,9 +20,6 @@
 
 #include <string>
 
-#ifndef APT_8_CLEANER_HEADERS
-#include <apt-pkg/indexfile.h>
-#endif
 
 class APT_HIDDEN debRecordParserBase : public pkgRecords::Parser
 {
@@ -86,7 +82,7 @@ class APT_HIDDEN debDebFileRecordParser : public debRecordParserBase
  public:
    virtual std::string FileName() APT_OVERRIDE;
 
-   debDebFileRecordParser(std::string FileName);
+   explicit debDebFileRecordParser(std::string FileName);
    virtual ~debDebFileRecordParser();
 };
 
