@@ -465,9 +465,14 @@ pid_t debSystem::ExecDpkg(std::vector<std::string> const &sArgs, int * const inp
 }
 									/*}}}*/
 bool debSystem::MultiArchSupported() const					/*{{{*/
+{
+   return AssertFeature("multi-arch");
+}
+									/*}}}*/
+bool debSystem::AssertFeature(std::string const &feature) /*{{{*/
 {
    std::vector<std::string> Args = GetDpkgBaseCommand();
-   Args.push_back("--assert-multi-arch");
+   Args.push_back("--assert-" + feature);
    pid_t const dpkgAssertMultiArch = ExecDpkg(Args, nullptr, nullptr, true);
    if (dpkgAssertMultiArch > 0)
    {
