@@ -15,9 +15,8 @@
 #include <apt-pkg/debversion.h>
 #include <apt-pkg/edspindexfile.h>
 #include <apt-pkg/edspsystem.h>
-#include <apt-pkg/pkgcache.h>
-#include <apt-pkg/cacheiterators.h>
 #include <apt-pkg/fileutl.h>
+#include <apt-pkg/pkgcache.h>
 
 #include <stddef.h>
 #include <stdlib.h>
@@ -40,7 +39,7 @@ eippSystem::eippSystem() : edspLikeSystem("Debian APT planner interface")
 }
 									/*}}}*/
 // System::Lock - Get the lock						/*{{{*/
-bool edspLikeSystem::Lock()
+bool edspLikeSystem::Lock(OpProgress *)
 {
    return true;
 }
