@@ -65,11 +65,8 @@ pkgIndexFile::pkgIndexFile(bool const Trusted) :			/*{{{*/
 }
 									/*}}}*/
 // IndexFile::ArchiveInfo - Stub					/*{{{*/
-std::string pkgIndexFile::ArchiveInfo(pkgCache::VerIterator const &Ver) const
+std::string pkgIndexFile::ArchiveInfo(pkgCache::VerIterator const &) const
 {
-   debDebPkgFileIndex const * const debfile = dynamic_cast<debDebPkgFileIndex const*>(this);
-   if (debfile != nullptr)
-      return debfile->ArchiveInfo_impl(Ver);
    return std::string();
 }
 									/*}}}*/
@@ -86,32 +83,6 @@ std::string pkgIndexFile::SourceInfo(pkgSrcRecords::Parser const &/*Record*/,
    return std::string();
 }
 									/*}}}*/
-// IndexFile::TranslationsAvailable - Check if will use Translation	/*{{{*/
-bool pkgIndexFile::TranslationsAvailable() {
-	return (APT::Configuration::getLanguages().empty() != true);
-}
-									/*}}}*/
-// IndexFile::CheckLanguageCode - Check the Language Code		/*{{{*/
-bool pkgIndexFile::CheckLanguageCode(const char * const Lang)
-{
-  if (strlen(Lang) == 2 || (strlen(Lang) == 5 && Lang[2] == '_'))
-    return true;
-
-  if (strcmp(Lang,"C") != 0)
-    _error->Warning("Wrong language code %s", Lang);
-
-  return false;
-}
-									/*}}}*/
-// IndexFile::LanguageCode - Return the Language Code			/*{{{*/
-std::string pkgIndexFile::LanguageCode() {
-APT_IGNORE_DEPRECATED_PUSH
-	if (TranslationsAvailable() == false)
-		return "";
-	return APT::Configuration::getLanguages()[0];
-APT_IGNORE_DEPRECATED_POP
-}
-									/*}}}*/
 
 // IndexTarget - Constructor						/*{{{*/
 IndexTarget::IndexTarget(std::string const &MetaKey, std::string const &ShortDesc,
@@ -149,6 +120,7 @@ std::string IndexTarget::Option(OptionKeys const EnumKey) const		/*{{{*/
       APT_CASE(ALLOW_WEAK);
       APT_CASE(ALLOW_DOWNGRADE_TO_INSECURE);
       APT_CASE(INRELEASE_PATH);
+      APT_CASE(SHADOWED);
 #undef APT_CASE
       case FILENAME:
       {
@@ -249,6 +221,8 @@ unsigned long pkgDebianIndexTargetFile::Size() const				/*{{{*/
 									/*}}}*/
 bool pkgDebianIndexTargetFile::Exists() const					/*{{{*/
 {
+   if (Target.OptionBool(IndexTarget::SHADOWED))
+      return false;
    return FileExists(IndexFileName());
 }
 									/*}}}*/
