@@ -99,7 +99,7 @@ template <typename T> class map_pointer {
    uint32_t val;
 public:
    map_pointer() noexcept : val(0) {}
-   map_pointer(nullptr_t) noexcept : val(0) {}
+   map_pointer(std::nullptr_t) noexcept : val(0) {}
    explicit map_pointer(uint32_t n) noexcept : val(n) {}
    explicit operator uint32_t() noexcept { return val; }
    explicit operator bool() noexcept { return val != 0; }
@@ -111,8 +111,8 @@ template<typename T> inline bool operator !=(map_pointer<T> u, map_pointer<T> m)
 template<typename T> inline bool operator <(map_pointer<T> u, map_pointer<T> m) { return uint32_t(u) < uint32_t(m); }
 template<typename T> inline bool operator >(map_pointer<T> u, map_pointer<T> m) { return uint32_t(u) > uint32_t(m); }
 template<typename T> inline uint32_t operator -(map_pointer<T> u, map_pointer<T> m) { return uint32_t(u) - uint32_t(m); }
-template<typename T> bool operator ==(map_pointer<T> m, nullptr_t) { return uint32_t(m) == 0; }
-template<typename T> bool operator !=(map_pointer<T> m, nullptr_t) { return uint32_t(m) != 0; }
+template<typename T> bool operator ==(map_pointer<T> m, std::nullptr_t) { return uint32_t(m) == 0; }
+template<typename T> bool operator !=(map_pointer<T> m, std::nullptr_t) { return uint32_t(m) != 0; }
 
 // same as the previous, but documented to be to a string item
 typedef map_pointer<char> map_stringitem_t;
