@@ -349,7 +349,6 @@ BaseHttpMethod::DealWithHeaders(FetchResult &Res, RequestState &Req)
 	       tmpURI.Access = base + '+' + tmpURI.Access;
 	       if (tmpURI.Access == Binary)
 	       {
-		  std::string tmpAccess = Uri.Access;
 		  std::swap(tmpURI.Access, Uri.Access);
 		  NextURI = tmpURI;
 		  std::swap(tmpURI.Access, Uri.Access);
@@ -871,7 +870,11 @@ unsigned long long BaseHttpMethod::FindMaximumObjectSizeInQueue() const	/*{{{*/
 {
    unsigned long long MaxSizeInQueue = 0;
    for (FetchItem *I = Queue; I != 0 && I != QueueBack; I = I->Next)
+   {
+      if (I->MaximumSize == 0)
+	 return 0;
       MaxSizeInQueue = std::max(MaxSizeInQueue, I->MaximumSize);
+   }
    return MaxSizeInQueue;
 }
 									/*}}}*/
